# qprop
Visualization tool for QPROP: A Schrödinger-solver for intense laser-atom interaction


# Citation
"Qprop is for non-profit use only. If results obtained using Qprop are published, an acknowledgment or citation is compulsory."

An example of citation would be like the following:

D. Bauer and P. Koval, Comput. Phys. Commun. 174, 396 (2006).

V. Mosert and D. Bauer, Comput. Phys. Commun. 207, 452 (2016).

